@@ -30,20 +30,25 @@ namespace Konsole
 {
 typedef unsigned char LineProperty;
 
+typedef quint16 RenditionFlags;
+
 const int LINE_DEFAULT      = 0;
 const int LINE_WRAPPED      = (1 << 0);
 const int LINE_DOUBLEWIDTH  = (1 << 1);
 const int LINE_DOUBLEHEIGHT = (1 << 2);
 
-const int DEFAULT_RENDITION = 0;
-const int RE_BOLD           = (1 << 0);
-const int RE_BLINK          = (1 << 1);
-const int RE_UNDERLINE      = (1 << 2);
-const int RE_REVERSE        = (1 << 3); // Screen only
-const int RE_INTENSIVE      = (1 << 3); // Widget only
-const int RE_ITALIC         = (1 << 4);
-const int RE_CURSOR         = (1 << 5);
-const int RE_EXTENDED_CHAR  = (1 << 6);
+const RenditionFlags DEFAULT_RENDITION = 0;
+const RenditionFlags RE_BOLD           = (1 << 0);
+const RenditionFlags RE_BLINK          = (1 << 1);
+const RenditionFlags RE_UNDERLINE      = (1 << 2);
+const RenditionFlags RE_REVERSE        = (1 << 3); // Screen only
+const RenditionFlags RE_ITALIC         = (1 << 4);
+const RenditionFlags RE_CURSOR         = (1 << 5);
+const RenditionFlags RE_EXTENDED_CHAR  = (1 << 6);
+const RenditionFlags RE_FAINT          = (1 << 7);
+const RenditionFlags RE_STRIKEOUT      = (1 << 8);
+const RenditionFlags RE_CONCEAL        = (1 << 9);
+const RenditionFlags RE_OVERLINE       = (1 << 10);
 
 /**
  * Unicode character in the range of U+2500 ~ U+257F are known as line
@@ -81,7 +86,7 @@ public:
     explicit inline Character(quint16 _c = ' ',
                               CharacterColor  _f = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_FORE_COLOR),
                               CharacterColor  _b = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_BACK_COLOR),
-                              quint8  _r = DEFAULT_RENDITION,
+                              RenditionFlags  _r = DEFAULT_RENDITION,
                               bool _real = true)
         : character(_c)
         , rendition(_r)
@@ -98,7 +103,7 @@ public:
     quint16 character;
 
     /** A combination of RENDITION flags which specify options for drawing the character. */
-    quint8  rendition;
+    RenditionFlags  rendition;
 
     /** The foreground color used to draw this character. */
     CharacterColor  foregroundColor;
