@@ -98,13 +98,11 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     , _copyToGroup(0)
     , _profileList(0)
     , _previousState(-1)
-    , _viewUrlFilter(0)
     , _searchFilter(0)
     , _copyInputToAllTabsAction(0)
     , _findAction(0)
     , _findNextAction(0)
     , _findPreviousAction(0)
-    , _urlFilterUpdateRequired(false)
     , _searchStartLine(0)
     , _prevSearchResultLine(0)
     , _searchBar(0)
@@ -142,6 +140,12 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     view->installEventFilter(this);
     view->setSessionController(this);
 
+    // install filter on the view to highlight URLs
+    _view->filterChain()->addFilter(new UrlFilter);
+
+    // install filter on the view to highlight Files
+    _view->filterChain()->addFilter(new FileFilter(_session));
+
     // listen for session resize requests
     connect(_session.data(), &Konsole::Session::resizeRequest, this, &Konsole::SessionController::sessionResizeRequest);
 
@@ -242,13 +246,6 @@ void SessionController::interactionHandler()
     _interactionTimer->start();
 }
 
-void SessionController::requireUrlFilterUpdate()
-{
-    // this method is called every time the screen window's output changes, so do not
-    // do anything expensive here.
-
-    _urlFilterUpdateRequired = true;
-}
 void SessionController::snapshot()
 {
     Q_ASSERT(_session != 0);
@@ -293,20 +290,19 @@ void SessionController::openUrl(const QUrl& url)
     // Clear shell's command line
     if (!_session->isForegroundProcessActive()
             && _bookmarkValidProgramsToClear.contains(_session->foregroundProcessName())) {
-        _session->emulation()->sendText(QChar(0x03)); // Ctrl+C
-        _session->emulation()->sendText(QChar('\n'));
+        _session->sendTextToTerminal(QChar(0x03), '\n'); // Ctrl+C
     }
 
     // handle local paths
     if (url.isLocalFile()) {
         QString path = url.toLocalFile();
-        _session->emulation()->sendText("cd " + KShell::quoteArg(path) + '\r');
+        _session->sendTextToTerminal("cd " + KShell::quoteArg(path), '\r');
     } else if (url.scheme().isEmpty()) {
         // QUrl couldn't parse what the user entered into the URL field
         // so just dump it to the shell
         QString command = url.toDisplayString();
         if (!command.isEmpty())
-            _session->emulation()->sendText(command + '\r');
+            _session->sendTextToTerminal(command, '\r');
     } else if (url.scheme() == "ssh") {
         QString sshCommand = "ssh ";
 
@@ -319,8 +315,7 @@ void SessionController::openUrl(const QUrl& url)
         if (!url.host().isEmpty()) {
             sshCommand += url.host();
         }
-
-        _session->sendText(sshCommand + '\r');
+        _session->sendTextToTerminal(sshCommand, '\r');
 
     } else if (url.scheme() == "telnet") {
         QString telnetCommand = "telnet ";
@@ -335,7 +330,7 @@ void SessionController::openUrl(const QUrl& url)
             telnetCommand += QString::number(url.port());
         }
 
-        _session->sendText(telnetCommand + '\r');
+        _session->sendTextToTerminal(telnetCommand, '\r');
 
     } else {
         //TODO Implement handling for other Url types
@@ -476,27 +471,6 @@ bool SessionController::eventFilter(QObject* watched , QEvent* event)
                 copyInputToAllTabs();
             }
         }
-        // when a mouse move is received, create the URL filter and listen for output changes if
-        // it has not already been created.  If it already exists, then update only if the output
-        // has changed since the last update ( _urlFilterUpdateRequired == true )
-        //
-        // also check that no mouse buttons are pressed since the URL filter only applies when
-        // the mouse is hovering over the view
-        if (event->type() == QEvent::MouseMove &&
-                (!_viewUrlFilter || _urlFilterUpdateRequired) &&
-                ((QMouseEvent*)event)->buttons() == Qt::NoButton) {
-            if (_view->screenWindow() && !_viewUrlFilter) {
-                connect(_view->screenWindow(), &Konsole::ScreenWindow::scrolled, this, &Konsole::SessionController::requireUrlFilterUpdate);
-                connect(_view->screenWindow(), &Konsole::ScreenWindow::outputChanged, this, &Konsole::SessionController::requireUrlFilterUpdate);
-
-                // install filter on the view to highlight URLs
-                _viewUrlFilter = new UrlFilter();
-                _view->filterChain()->addFilter(_viewUrlFilter);
-            }
-
-            _view->processFilters();
-            _urlFilterUpdateRequired = false;
-        }
     }
 
     return false;
@@ -1174,14 +1148,23 @@ bool SessionController::reverseSearchChecked() const
     return options.at(IncrementalSearchBar::ReverseSearch);
 }
 
-QRegExp SessionController::regexpFromSearchBarOptions()
+QRegularExpression SessionController::regexpFromSearchBarOptions() const
 {
     QBitArray options = _searchBar->optionsChecked();
 
-    Qt::CaseSensitivity caseHandling = options.at(IncrementalSearchBar::MatchCase) ? Qt::CaseSensitive : Qt::CaseInsensitive;
-    QRegExp::PatternSyntax syntax = options.at(IncrementalSearchBar::RegExp) ? QRegExp::RegExp : QRegExp::FixedString;
+    QString text(_searchBar->searchText());
+
+    QRegularExpression regExp;
+    if (options.at(IncrementalSearchBar::RegExp)) {
+        regExp.setPattern(text);
+    } else {
+        regExp.setPattern(QRegularExpression::escape(text));
+    }
+
+    if (!options.at(IncrementalSearchBar::MatchCase)) {
+        regExp.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    }
 
-    QRegExp regExp(_searchBar->searchText(),  caseHandling , syntax);
     return regExp;
 }
 
@@ -1249,7 +1232,7 @@ void SessionController::beginSearch(const QString& text , int direction)
     Q_ASSERT(_searchBar);
     Q_ASSERT(_searchFilter);
 
-    QRegExp regExp = regexpFromSearchBarOptions();
+    QRegularExpression regExp = regexpFromSearchBarOptions();
     _searchFilter->setRegExp(regExp);
 
     if (_searchStartLine == -1) {
@@ -1260,7 +1243,7 @@ void SessionController::beginSearch(const QString& text , int direction)
         }
     }
 
-    if (!regExp.isEmpty()) {
+    if (!regExp.pattern().isEmpty()) {
         _view->screenWindow()->setCurrentResultLine(-1);
         SearchHistoryTask* task = new SearchHistoryTask(this);
 
@@ -1633,10 +1616,11 @@ void SessionController::zmodemUpload()
 bool SessionController::isKonsolePart() const
 {
     // Check to see if we are being called from Konsole or a KPart
-    if (QString(qApp->metaObject()->className()) == "Konsole::Application")
+    if (qApp->applicationName() == "konsole") {
         return false;
-    else
+    } else {
         return true;
+    }
 }
 
 SessionTask::SessionTask(QObject* parent)
@@ -1810,7 +1794,7 @@ void SearchHistoryTask::executeOnScreenWindow(SessionPtr session , ScreenWindowP
 
     Emulation* emulation = session->emulation();
 
-    if (!_regExp.isEmpty()) {
+    if (!_regExp.pattern().isEmpty()) {
         int pos = -1;
         const bool forwards = (_direction == ForwardsSearch);
         const int lastLine = window->lineCount() - 1;
@@ -1962,11 +1946,11 @@ SearchHistoryTask::SearchDirection SearchHistoryTask::searchDirection() const
 {
     return _direction;
 }
-void SearchHistoryTask::setRegExp(const QRegExp& expression)
+void SearchHistoryTask::setRegExp(const QRegularExpression &expression)
 {
     _regExp = expression;
 }
-QRegExp SearchHistoryTask::regExp() const
+QRegularExpression SearchHistoryTask::regExp() const
 {
     return _regExp;
 }
