@@ -85,6 +85,11 @@ ViewSplitter* ViewSplitter::activeSplitter()
 void ViewSplitter::registerContainer(ViewContainer* container)
 {
     _containers << container;
+    // Connecting to container::destroyed() using the new-style connection
+    // syntax causes a crash at exit. I don't know why. Using the old-style
+    // syntax works.
+    //connect(container , static_cast<void(ViewContainer::*)(ViewContainer*)>(&Konsole::ViewContainer::destroyed) , this , &Konsole::ViewSplitter::containerDestroyed);
+    //connect(container , &Konsole::ViewContainer::empty , this , &Konsole::ViewSplitter::containerEmpty);
     connect(container , SIGNAL(destroyed(ViewContainer*)) , this , SLOT(containerDestroyed(ViewContainer*)));
     connect(container , SIGNAL(empty(ViewContainer*)) , this , SLOT(containerEmpty(ViewContainer*)));
 }
@@ -145,7 +150,7 @@ void ViewSplitter::addContainer(ViewContainer* container ,
         splitter->updateSizes();
     } else {
         ViewSplitter* newSplitter = new ViewSplitter(this);
-        connect(newSplitter , SIGNAL(empty(ViewSplitter*)) , splitter , SLOT(childEmpty(ViewSplitter*)));
+        connect(newSplitter , &Konsole::ViewSplitter::empty , splitter , &Konsole::ViewSplitter::childEmpty);
 
         ViewContainer* oldContainer = splitter->activeContainer();
         const int oldContainerIndex = splitter->indexOf(oldContainer->containerWidget());
@@ -257,4 +262,3 @@ ViewContainer* ViewSplitter::activeContainer() const
     }
 }
 
-#include "ViewSplitter.moc"
